@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,11 +26,11 @@ class SieveActionAddHeader : public SieveActionAbstractEditHeader
     Q_OBJECT
 public:
     explicit SieveActionAddHeader(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent = nullptr);
-    QString code(QWidget *w) const override;
-    QWidget *createParamWidget(QWidget *parent) const override;
-    bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
-    QString help() const override;
-    QUrl href() const override;
+    Q_REQUIRED_RESULT QString code(QWidget *w) const override;
+    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
+    Q_REQUIRED_RESULT bool setParamWidgetValue(QXmlStreamReader &element, QWidget *parent, QString &error) override;
+    Q_REQUIRED_RESULT QString help() const override;
+    Q_REQUIRED_RESULT QUrl href() const override;
 };
 }
 
