@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,11 +23,9 @@
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
 #include <KLocalizedString>
 
-#include <KPluginLoader>
 #include <QCheckBox>
 #include <QHBoxLayout>
 #include "libksieve_debug.h"
-#include <KPluginFactory>
 #include <QXmlStreamReader>
 //Add support for adding flags
 using namespace KSieveUi;
