@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,6 +28,7 @@
 #include <QHBoxLayout>
 #include "libksieve_debug.h"
 #include <QXmlStreamReader>
+#include <KSieveUi/AbstractMoveImapFolderWidget>
 
 using namespace KSieveUi;
 SieveConditionMetaData::SieveConditionMetaData(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
@@ -39,7 +40,7 @@ QWidget *SieveConditionMetaData::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
 
     SelectMatchTypeComboBox *selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
@@ -48,14 +49,15 @@ QWidget *SieveConditionMetaData::createParamWidget(QWidget *parent) const
     lay->addWidget(selectType);
 
     QGridLayout *grid = new QGridLayout;
-    grid->setMargin(0);
+    grid->setContentsMargins(0, 0, 0, 0);
     lay->addLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Mailbox:"));
     grid->addWidget(lab, 0, 0);
 
-    QLineEdit *mailbox = new QLineEdit;
-    connect(mailbox, &QLineEdit::textChanged, this, &SieveConditionMetaData::valueChanged);
+    KSieveUi::AbstractMoveImapFolderWidget *mailbox = AutoCreateScriptUtil::createImapFolderWidget();
+
+    connect(mailbox, &KSieveUi::AbstractMoveImapFolderWidget::textChanged, this, &SieveConditionMetaData::valueChanged);
     mailbox->setObjectName(QStringLiteral("mailbox"));
     grid->addWidget(mailbox, 0, 1);
 
@@ -87,7 +89,7 @@ QString SieveConditionMetaData::code(QWidget *w) const
 
     QString result = AutoCreateScriptUtil::negativeString(isNegative) + QStringLiteral("metadata %1 ").arg(matchString);
 
-    const QLineEdit *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
+    const KSieveUi::AbstractMoveImapFolderWidget *mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
     const QString mailboxStr = mailbox->text();
 
     result += QStringLiteral("\"%1\" ").arg(mailboxStr);
@@ -137,7 +139,7 @@ bool SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
             switch (index) {
             case 0:
             {
-                QLineEdit *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
+                KSieveUi::AbstractMoveImapFolderWidget *mailbox = w->findChild<KSieveUi::AbstractMoveImapFolderWidget *>(QStringLiteral("mailbox"));
                 mailbox->setText(tagValue);
                 break;
             }
@@ -154,7 +156,7 @@ bool SieveConditionMetaData::setParamWidgetValue(QXmlStreamReader &element, QWid
                 break;
             }
             default:
-                tooManyArgument(tagName, index, 3, error);
+                tooManyArguments(tagName, index, 3, error);
                 qCDebug(LIBKSIEVE_LOG) << " SieveConditionMetaData::setParamWidgetValue too many argument " << index;
                 break;
             }
