@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -28,33 +28,28 @@
 #include <QHBoxLayout>
 #include "libksieve_debug.h"
 #include <QLabel>
-#include <QDomNode>
+#include <QXmlStreamReader>
 
 using namespace KSieveUi;
-SieveConditionServerMetaData::SieveConditionServerMetaData(QObject *parent)
-    : SieveCondition(QStringLiteral("servermetadata"), i18n("Server Meta Data"), parent)
+SieveConditionServerMetaData::SieveConditionServerMetaData(SieveEditorGraphicalModeWidget *sieveGraphicalModeWidget, QObject *parent)
+    : SieveCondition(sieveGraphicalModeWidget, QStringLiteral("servermetadata"), i18n("Server Meta Data"), parent)
 {
 }
 
-SieveCondition *SieveConditionServerMetaData::newAction()
-{
-    return new SieveConditionServerMetaData;
-}
-
 QWidget *SieveConditionServerMetaData::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
-    lay->setMargin(0);
+    lay->setContentsMargins(0, 0, 0, 0);
     w->setLayout(lay);
 
-    SelectMatchTypeComboBox *selectType = new SelectMatchTypeComboBox;
+    SelectMatchTypeComboBox *selectType = new SelectMatchTypeComboBox(mSieveGraphicalModeWidget);
     selectType->setObjectName(QStringLiteral("selecttype"));
     connect(selectType, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionServerMetaData::valueChanged);
     lay->addWidget(selectType);
 
     QGridLayout *grid = new QGridLayout;
-    grid->setMargin(0);
+    grid->setContentsMargins(0, 0, 0, 0);
     lay->addLayout(grid);
 
     QLabel *lab = new QLabel(i18n("Mailbox:"));
@@ -76,8 +71,9 @@ QWidget *SieveConditionServerMetaData::createParamWidget(QWidget *parent) const
     lab = new QLabel(i18n("Value:"));
     grid->addWidget(lab, 2, 0);
 
-    QLineEdit *value = new QLineEdit;
-    connect(value, &QLineEdit::textChanged, this, &SieveConditionServerMetaData::valueChanged);
+    AbstractRegexpEditorLineEdit *value = AutoCreateScriptUtil::createRegexpEditorLineEdit();
+    connect(value, &AbstractRegexpEditorLineEdit::textChanged, this, &SieveConditionServerMetaData::valueChanged);
+    connect(selectType, &SelectMatchTypeComboBox::switchToRegexp, value, &AbstractRegexpEditorLineEdit::switchToRegexpEditorLineEdit);
     value->setObjectName(QStringLiteral("value"));
     grid->addWidget(value, 2, 1);
 
@@ -102,16 +98,17 @@ QString SieveConditionServerMetaData::code(QWidget *w) const
 
     result += QStringLiteral("\"%1\" ").arg(annotationStr);
 
-    const QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
-    const QString valueStr = value->text();
+    const AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+    const QString valueStr = value->code();
 
     result += QStringLiteral("\"%1\"").arg(valueStr);
-    return result;
+    return result + AutoCreateScriptUtil::generateConditionComment(comment());
 }
 
-QStringList SieveConditionServerMetaData::needRequires(QWidget *) const
+QStringList SieveConditionServerMetaData::needRequires(QWidget *w) const
 {
-    return QStringList() << QStringLiteral("servermetadata");
+    const SelectMatchTypeComboBox *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
+    return QStringList() << QStringLiteral("servermetadata") << selectType->needRequires();
 }
 
 bool SieveConditionServerMetaData::needCheckIfServerHasCapability() const
@@ -126,56 +123,60 @@ QString SieveConditionServerMetaData::serverNeedsCapability() const
 
 QString SieveConditionServerMetaData::help() const
 {
-    return i18n("This test retrieves the value of the server annotation \"annotation-name\".  The retrieved value is compared to the \"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
+    return i18n(
+        "This test retrieves the value of the server annotation \"annotation-name\".  The retrieved value is compared to the \"key-list\". The test returns true if the annotation exists and its value matches any of the keys.");
 }
 
-bool SieveConditionServerMetaData::setParamWidgetValue(const QDomElement &element, QWidget *w, bool notCondition, QString &error)
+bool SieveConditionServerMetaData::setParamWidgetValue(QXmlStreamReader &element, QWidget *w, bool notCondition, QString &error)
 {
     int index = 0;
-    QDomNode node = element.firstChild();
-    while (!node.isNull()) {
-        QDomElement e = node.toElement();
-        if (!e.isNull()) {
-            const QString tagName = e.tagName();
-            if (tagName == QLatin1String("str")) {
-                const QString tagValue = e.text();
-                switch (index) {
-                case 0: {
-                    QLineEdit *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
-                    mailbox->setText(tagValue);
-                    break;
-                }
-                case 1: {
-                    QLineEdit *annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
-                    annotation->setText(tagValue);
-                    break;
-                }
-                case 2: {
-                    QLineEdit *value = w->findChild<QLineEdit *>(QStringLiteral("value"));
-                    value->setText(tagValue);
-                    break;
-                }
-                default: {
-                    tooManyArgument(tagName, index, 3, error);
-                    qCDebug(LIBKSIEVE_LOG) << " SieveConditionServerMetaData::setParamWidgetValue too many argument " << index;
-                    break;
-                }
-                }
-                ++index;
-            } else if (tagName == QLatin1String("tag")) {
-                SelectMatchTypeComboBox *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
-                selectType->setCode(AutoCreateScriptUtil::tagValueWithCondition(e.text(), notCondition), name(), error);
-            } else if (tagName == QLatin1String("crlf")) {
-                //nothing
-            } else if (tagName == QLatin1String("comment")) {
-                //implement in the future ?
-            } else {
-                unknownTag(tagName, error);
-                qCDebug(LIBKSIEVE_LOG) << " SieveConditionServerMetaData::setParamWidgetValue unknown tagName " << tagName;
+    QString commentStr;
+    while (element.readNextStartElement()) {
+        const QStringRef tagName = element.name();
+        if (tagName == QLatin1String("str")) {
+            const QString tagValue = element.readElementText();
+            switch (index) {
+            case 0:
+            {
+                QLineEdit *mailbox = w->findChild<QLineEdit *>(QStringLiteral("mailbox"));
+                mailbox->setText(tagValue);
+                break;
             }
+            case 1:
+            {
+                QLineEdit *annotation = w->findChild<QLineEdit *>(QStringLiteral("annotation"));
+                annotation->setText(tagValue);
+                break;
+            }
+            case 2:
+            {
+                AbstractRegexpEditorLineEdit *value = w->findChild<AbstractRegexpEditorLineEdit *>(QStringLiteral("value"));
+                value->setCode(tagValue);
+                break;
+            }
+            default:
+                tooManyArguments(tagName, index, 3, error);
+                qCDebug(LIBKSIEVE_LOG) << " SieveConditionServerMetaData::setParamWidgetValue too many argument " << index;
+                break;
+            }
+            ++index;
+        } else if (tagName == QLatin1String("tag")) {
+            SelectMatchTypeComboBox *selectType = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("selecttype"));
+            selectType->setCode(AutoCreateScriptUtil::tagValueWithCondition(element.readElementText(), notCondition), name(), error);
+        } else if (tagName == QLatin1String("crlf")) {
+            element.skipCurrentElement();
+            //nothing
+        } else if (tagName == QLatin1String("comment")) {
+            commentStr = AutoCreateScriptUtil::loadConditionComment(commentStr, element.readElementText());
+        } else {
+            unknownTag(tagName, error);
+            qCDebug(LIBKSIEVE_LOG) << " SieveConditionServerMetaData::setParamWidgetValue unknown tagName " << tagName;
         }
-        node = node.nextSibling();
     }
+    if (!commentStr.isEmpty()) {
+        setComment(commentStr);
+    }
+
     return true;
 }
 
