@@ -34,11 +34,9 @@ using namespace KSieveUi;
 
 SieveDebugDialog::SieveDebugDialog(SieveImapPasswordProvider *passwordProvider, QWidget *parent)
     : QDialog(parent)
-    , mSieveJob(nullptr)
     , mPasswordProvider(passwordProvider)
-    , mShutDownJob(nullptr)
 {
-    setWindowTitle(i18n("Sieve Diagnostics"));
+    setWindowTitle(i18nc("@title:window", "Sieve Diagnostics"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
 
     // Collect all accounts
@@ -175,8 +173,18 @@ void SieveDebugDialog::slotDiagNextScript()
 void SieveDebugDialog::slotGetScript(KManageSieve::SieveJob *job, bool success, const QString &script, bool active)
 {
     qCDebug(LIBKSIEVE_LOG) << "( ??," << success
-                           << ", ?," << active << ")" << endl
-                           << "script:" << endl
+                           << ", ?," << active << ")"
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                           << endl
+                          #else
+                           << Qt::endl
+                          #endif
+                           << "script:"
+                          #if (QT_VERSION < QT_VERSION_CHECK(5, 15, 0))
+                           << endl
+                          #else
+                           << Qt::endl
+                          #endif
                            << script;
     mSieveJob = nullptr; // job deletes itself after returning from this slot!
 
