@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+  Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,10 +26,8 @@
 #include "util/sieveimapaccountsettings.h"
 
 #include <KLocalizedString>
-#include <kiconloader.h>
-#include <kwindowsystem.h>
 #include <QPushButton>
-#include <kmessagebox.h>
+#include <KMessageBox>
 #include <KConfigGroup>
 
 #include <kmanagesieve/sievejob.h>
@@ -81,12 +79,10 @@ ManageSieveScriptsDialog::ManageSieveScriptsDialog(SieveImapPasswordProvider *pa
     : QDialog(parent)
     , d(new KSieveUi::ManageSieveScriptsDialogPrivate)
 {
-    setWindowTitle(i18n("Manage Sieve Scripts"));
+    setWindowTitle(i18nc("@title:window", "Manage Sieve Scripts"));
     setModal(false);
     setAttribute(Qt::WA_GroupLeader);
     setAttribute(Qt::WA_DeleteOnClose);
-    KWindowSystem::setIcons(winId(), qApp->windowIcon().pixmap(IconSize(KIconLoader::Desktop), IconSize(KIconLoader::Desktop)),
-                            qApp->windowIcon().pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small)));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QFrame *frame = new QFrame;
     mainLayout->addWidget(frame);
@@ -139,7 +135,7 @@ ManageSieveScriptsDialog::~ManageSieveScriptsDialog()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "ManageSieveScriptsDialog");
     group.writeEntry("Size", size());
-    // prevent QTreeWidget signals triggered by it's desctructor from calling our slots
+    // prevent QTreeWidget signals triggered by it's destructor from calling our slots
     d->mTreeView->disconnect(this);
     delete d;
 }
@@ -277,7 +273,7 @@ void ManageSieveScriptsDialog::slotPutResult(KManageSieve::SieveJob *job, bool s
     } else {
         //Don't add parent otherwise when there is an error it will parent to ManageSieveScriptsDialog and not editor
         KMessageBox::error(nullptr, i18n("Uploading the Sieve script failed.\n"
-                                      "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
+                                         "The server responded:\n%1", job->errorString()), i18n("Sieve Error"));
         if (d->mSieveEditor) {
             d->mSieveEditor->show();
         }
