@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -45,7 +45,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     : QWidget(parent)
 {
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
 
     QFormLayout *formLayout = new QFormLayout;
     mainLayout->addLayout(formLayout);
@@ -82,7 +82,7 @@ SieveScriptDebuggerFrontEndWidget::SieveScriptDebuggerFrontEndWidget(QWidget *pa
     QWidget *sieveEditorWidget = new QWidget(this);
     QVBoxLayout *vboxSieveEditorLayout = new QVBoxLayout;
     sieveEditorWidget->setLayout(vboxSieveEditorLayout);
-    vboxSieveEditorLayout->setMargin(0);
+    vboxSieveEditorLayout->setContentsMargins(0, 0, 0, 0);
 
     KPIMTextEdit::TextToSpeechWidget *textToSpeechWidget = new KPIMTextEdit::TextToSpeechWidget(this);
     textToSpeechWidget->setObjectName(QStringLiteral("texttospeechwidget"));
@@ -156,7 +156,7 @@ void SieveScriptDebuggerFrontEndWidget::slotDebugScript()
 
     QTemporaryFile *temporaryFile = new QTemporaryFile();
     if (!temporaryFile->open()) {
-        mSieveScriptDebuggerWarning->setErrorMessage(i18n("Impossible to open temporary file."));
+        mSieveScriptDebuggerWarning->setErrorMessage(i18n("Failed to open temporary file."));
         delete temporaryFile;
         return;
     }
