@@ -61,8 +61,7 @@ KSieveUi::Util::AccountInfo KSieveUi::Util::fullAccountInfo(const QString &ident
     return accountInfo;
 }
 
-KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName,
-                                                            std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface)
+KSieveUi::Util::AccountInfo KSieveUi::Util::findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName, std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface)
 {
     KSieveUi::Util::AccountInfo accountInfo;
     if (!interface) {
@@ -265,9 +264,15 @@ bool KSieveUi::Util::allowOutOfOfficeSettings()
     return VacationSettings::self()->allowOutOfOfficeSettings();
 }
 
-bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringList &availableScripts, const QString &activeScript)
+bool Util::hasKep14CapabilitySupport(const QStringList &sieveCapabilities)
 {
     const bool hasIncludeCapability = sieveCapabilities.contains(QLatin1String("include"));
+    return hasIncludeCapability;
+}
+
+bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringList &availableScripts, const QString &activeScript)
+{
+    const bool hasIncludeCapability = Util::hasKep14CapabilitySupport(sieveCapabilities);
     if (!hasIncludeCapability) {
         return false;
     }
@@ -275,7 +280,7 @@ bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringLi
     bool masterIsActive = !activeScript.isEmpty();
     if (masterIsActive) {
         const QString scriptName = activeScript.split(QLatin1Char('.')).first().toLower();
-        masterIsActive = (scriptName == QStringLiteral("master") || scriptName == QStringLiteral("user"));
+        masterIsActive = (scriptName == QLatin1String("master") || scriptName == QLatin1String("user"));
     }
     if (!masterIsActive) {
         return false;
@@ -287,7 +292,7 @@ bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringLi
             continue;
         }
         const QString name = script.split(QLatin1Char('.')).first().toLower();
-        if (name == QStringLiteral("user")) {
+        if (name == QLatin1String("user")) {
             hasUserScript = true;
             break;
         }
@@ -299,9 +304,9 @@ bool Util::hasKep14Support(const QStringList &sieveCapabilities, const QStringLi
 bool Util::isKep14ProtectedName(const QString &name)
 {
     const QString n = name.split(QLatin1Char('.')).first().toLower();
-    if (n == QStringLiteral("master")
-        || n == QStringLiteral("user")
-        || n == QStringLiteral("management")) {
+    if (n == QLatin1String("master")
+        || n == QLatin1String("user")
+        || n == QLatin1String("management")) {
         return true;
     }
     return false;
