@@ -39,12 +39,11 @@
 #ifndef KSIEVE_KSIEVEUI_UTIL_P_H
 #define KSIEVE_KSIEVEUI_UTIL_P_H
 
-#include "ksieveui_private_export.h"
+#include "ksieveui_export.h"
 #include <KSieveUi/SieveImapAccountSettings>
 #include <KSieveUi/SieveImapInstance>
 #include <memory>
-
-class QUrl;
+#include <QUrl>
 class QString;
 class QStringList;
 
@@ -59,9 +58,9 @@ namespace Util {
 struct AccountInfo {
     KSieveUi::SieveImapAccountSettings sieveImapAccountSettings;
     QUrl sieveUrl;
-    KSIEVEUI_TESTS_EXPORT bool operator==(const AccountInfo &other) const;
+    KSIEVEUI_EXPORT bool operator==(const AccountInfo &other) const;
 };
-KSIEVEUI_TESTS_EXPORT QDebug operator <<(QDebug d, const Util::AccountInfo &info);
+KSIEVEUI_EXPORT QDebug operator <<(QDebug d, const Util::AccountInfo &info);
 
 /**
  * Returns the list of configured IMAP agent instances.
@@ -74,18 +73,19 @@ QStringList sieveImapResourceNames();
  */
 bool hasKep14Support(const QStringList &sieveCapabilities, const QStringList &availableScripts, const QString &activeScript);
 
+bool hasKep14CapabilitySupport(const QStringList &sieveCapabilities);
+
 /**
  * Is the given scriptName a protected KEP:14 name, that a normal user should not touch directly.
  * it tests against MASTER, USER and MANAGEMENT script
  */
 bool isKep14ProtectedName(const QString &scriptName);
 
-KSIEVEUI_TESTS_EXPORT KSieveUi::Util::AccountInfo findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName,
-                                                                  std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface);
+KSIEVEUI_EXPORT KSieveUi::Util::AccountInfo findAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName, std::unique_ptr<KSieveUi::AbstractAkonadiImapSettingInterface> &interface);
 /**
  * Returns all sieve account info with the given @p identifier.
  */
-KSIEVEUI_TESTS_EXPORT KSieveUi::Util::AccountInfo fullAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName = true);
+KSIEVEUI_EXPORT KSieveUi::Util::AccountInfo fullAccountInfo(const QString &identifier, SieveImapPasswordProvider *provider, bool withVacationFileName = true);
 }
 }
 
