@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -190,7 +190,11 @@ VacationEditWidget::VacationEditWidget(QWidget *parent)
         mMailAction->addItem(VacationUtils::mailAction(static_cast<VacationUtils::MailAction>(i)));
     }
     mMailAction->setObjectName(QStringLiteral("mMailAction"));
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     connect(mMailAction, QOverload<int>::of(&QComboBox::currentIndexChanged), this, &VacationEditWidget::mailActionChanged);
+#else
+    connect(mMailAction, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), this, &VacationEditWidget::mailActionChanged);
+#endif
 
     //Add imap select folder plugin here.
     mMailActionRecipient = new VacationMailActionWidget(this);
