@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -376,20 +376,30 @@ QString KSieveUi::VacationUtils::mergeRequireLine(const QString &script, const Q
         for (int i = insert; i <= endOld; ++i) {
             lines.removeAt(insert);
         }
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         requirements = rx.requirements().toSet();
+#else
+        const auto requirementsSet = rx.requirements();
+        requirements = QSet<QString>(requirementsSet.begin(), requirementsSet.end());
+#endif
     }
 
     if (parserUpdate.parse() && rxUpdate.commandFound()) {
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
         requirements += rxUpdate.requirements().toSet();
+#else
+        const auto requirementsSet = rxUpdate.requirements();
+        requirements += QSet<QString>(requirementsSet.begin(), requirementsSet.end());
+#endif
     }
 
     const int requirementscount = requirements.count();
     if (requirementscount > 1) {
-        QStringList req = requirements.toList();
+        QStringList req = requirements.values();
         req.sort();
         lines.insert(insert, QStringLiteral("require [\"%1\"];").arg(req.join(QStringLiteral("\", \""))));
     } else if (requirementscount == 1) {
-        lines.insert(insert, QStringLiteral("require \"%1\";").arg(requirements.toList().at(0)));
+        lines.insert(insert, QStringLiteral("require \"%1\";").arg(requirements.values().at(0)));
     }
 
     return lines.join(QLatin1Char('\n'));
